@@ -1,5 +1,5 @@
 /* This file is part of GNU Rush.                  
-   Copyright (C) 2008-2019 Sergey Poznyakoff
+   Copyright (C) 2008-2025 Sergey Poznyakoff
 
    GNU Rush is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -17,6 +17,8 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <gettext.h>
+#include <sys/stat.h>
+#include <sys/time.h>
 
 #define N_(s) s
 #define _(s) gettext(s)
@@ -130,9 +132,6 @@ slist_t slist_create(void);
 void slist_free(slist_t slist);
 char *slist_alloc(slist_t slist, size_t len);
 
-
-void version(const char *progname);
-
 
 typedef struct rushdb_format *rushdb_format_t;
 extern char *rushdb_date_format;
@@ -153,4 +152,5 @@ const char *user_gettext(const char *locale, const char *domain,
 
 void argcv_free(int argc, char **argv);
 char *argcv_string(int argc, char **argv);
-
+
+int wildmatch(char const *expr, char const *name, size_t len);
