@@ -1,5 +1,5 @@
 /* This file is part of GNU Rush.                  
-   Copyright (C) 2008-2024 Sergey Poznyakoff
+   Copyright (C) 2008-2025 Sergey Poznyakoff
 
    GNU Rush is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -19,18 +19,24 @@
 #endif
 #include <librush.h>
 #include <stdio.h>
+#include <parseopt.h>
 
-void
-version(const char *progname)
-{
-        printf("%s (%s) %s\n", progname, PACKAGE, PACKAGE_VERSION);
-        fputs("Copyright (C) 2008-2017 Sergey Poznyakoff\n", stdout);
-        fputs(_("\
+static int copyright_year = 2025;
+static char gplv3[] = N_("\
 \n\
 License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n\
 This is free software: you are free to change and redistribute it.\n\
 There is NO WARRANTY, to the extent permitted by law.\n\
 \n\
-"), stdout);
+");
+
+void
+version_hook(WORDWRAP_FILE wf, struct parseopt *po)
+{
+	wordwrap_printf(wf, "%s (%s) %s\n",
+			po->po_program_name, PACKAGE_NAME, PACKAGE_VERSION);
+	wordwrap_printf(wf, "Copyright %s 2008-%d Sergey Poznyakoff\n",
+			_("(C)"),
+			copyright_year);
+	wordwrap_puts(wf, gplv3);
 }
-        
